Subject: <what happen when you do on which django project>

### Problem
- <Detail of problem>

#### Procedure to reproduce the problem
```
<Paste your traceback here which cause the problem>
```

#### Error logs / results
```
<Paste your error log here>
```
- <public link of unexpected result if you have>

#### Expected results
<Describe what to actually do>

### Environment info
- OS: <Unix/Linux/Mac/Win/other with version>
- Python version:
- Django version:
- Django-Redshift-Backend version: 
